@@ -4,10 +4,10 @@
 
 
 from dataclasses import dataclass
-from typing import Union, Optional, List
+from typing import List
 
 from .input_file import InputFile
-from .mask_position import MaskPosition
+from .input_sticker import InputSticker
 from .request import Request
 from .utils import BoolResultMixin
 
@@ -21,16 +21,9 @@ class AddStickerToSet(BoolResultMixin, Request):
 
     user_id: int
     name: str
-    emojis: str
-    png_sticker: Optional[Union[InputFile, str]] = None
-    tgs_sticker: Optional[InputFile] = None
-    webm_sticker: Optional[InputFile] = None
-    mask_position: Optional[MaskPosition] = None
+    sticker: InputSticker
 
     def files(self) -> List[InputFile]:
-        files = list()
-        if isinstance(self.png_sticker, InputFile):
-            files.append(self.png_sticker)
-        if self.tgs_sticker is not None:
-            files.append(self.tgs_sticker)
-        return files
+        if isinstance(self.sticker.sticker, InputFile):
+            return [self.sticker.sticker]
+        return list()
