@@ -24,7 +24,7 @@ class InlineQueryResultPhoto(InlineQueryResult):
 
     id: str
     photo_url: str
-    thumb_url: str
+    thumbnail_url: str
     photo_width: Optional[int] = None
     photo_height: Optional[int] = None
     title: Optional[str] = None
