@@ -25,7 +25,7 @@ class InlineQueryResultVideo(InlineQueryResult):
     id: str
     video_url: str
     mime_type: str
-    thumb_url: str
+    thumbnail_url: str
     title: str
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
