@@ -22,10 +22,11 @@ class InputMediaAnimation(InputMedia):
     type: str = field(init=False, default='animation')
 
     media: Union[InputFile, str]
-    thumb: Optional[Union[InputFile, str]] = None
+    thumbnail: Optional[Union[InputFile, str]] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
     caption_entities: Optional[List[MessageEntity]] = None
     width: Optional[int] = None
     height: Optional[int] = None
     duration: Optional[int] = None
+    has_spoiler: Optional[bool] = None
