@@ -22,7 +22,7 @@ class InputMediaDocument(InputMedia):
     type: str = field(init=False, default='document')
 
     media: Union[InputFile, str]
-    thumb: Optional[Union[InputFile, str]] = None
+    thumbnail: Optional[Union[InputFile, str]] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
     caption_entities: Optional[List[MessageEntity]] = None
