@@ -22,7 +22,7 @@ class InputMediaVideo(InputMedia):
     type: str = field(init=False, default='video')
 
     media: Union[InputFile, str]
-    thumb: Optional[Union[InputFile, str]] = None
+    thumbnail: Optional[Union[InputFile, str]] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
     caption_entities: Optional[List[MessageEntity]] = None
@@ -30,3 +30,4 @@ class InputMediaVideo(InputMedia):
     height: Optional[int] = None
     duration: Optional[int] = None
     supports_streaming: Optional[bool] = None
+    has_spoiler: Optional[bool] = None
