@@ -37,9 +37,18 @@ class MessageType(EnumAutoName):
     pinned_message = auto()
     invoice = auto()
     successful_payment = auto()
+    user_shared = auto()
+    chat_shared = auto()
     connected_website = auto()
+    write_access_allowed = auto()
     passport_data = auto()
     proximity_alert_triggered = auto()
+    forum_topic_created = auto()
+    forum_topic_edited = auto()
+    forum_topic_closed = auto()
+    forum_topic_reopened = auto()
+    general_forum_topic_hidden = auto()
+    general_forum_topic_unhidden = auto()
     video_chat_scheduled = auto()
     video_chat_started = auto()
     video_chat_ended = auto()
