@@ -3,7 +3,6 @@
 # Rocketgram is released under the MIT License (see LICENSE).
 
 
-import warnings
 from dataclasses import dataclass, asdict
 from datetime import datetime
 from enum import Enum
@@ -74,11 +73,6 @@ class Request:
 
         raise NotImplementedError
 
-    async def send2(self):
-        warnings.warn("This method is deprecated. Use send() instead.", DeprecationWarning)
-
-        return await self.send()
-
     def webhook(self):
         """\
         Schedules sending this request through the webhook-request mechanism.
