@@ -22,13 +22,15 @@ class SendAnimation(MessageResultMixin, Request):
 
     chat_id: Union[int, str]
     animation: Union[InputFile, str]
+    message_thread_id: Optional[int] = None
     duration: Optional[int] = None
     width: Optional[int] = None
     height: Optional[int] = None
-    thumb: Optional[Union[InputFile, str]] = None
+    thumbnail: Optional[Union[InputFile, str]] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
     caption_entities: Optional[List[MessageEntity]] = None
+    has_spoiler: Optional[bool] = None
     disable_notification: Optional[bool] = None
     protect_content: Optional[bool] = None
     reply_to_message_id: Optional[int] = None
@@ -39,6 +41,6 @@ class SendAnimation(MessageResultMixin, Request):
         out = list()
         if isinstance(self.animation, InputFile):
             out.append(self.animation)
-        if isinstance(self.thumb, InputFile):
-            out.append(self.thumb)
+        if isinstance(self.thumbnail, InputFile):
+            out.append(self.thumbnail)
         return out
