@@ -4,7 +4,7 @@
 
 
 from dataclasses import dataclass
-from typing import Union
+from typing import Union, Optional
 
 from .chat_action_type import ChatActionType
 from .request import Request
@@ -20,3 +20,4 @@ class SendChatAction(BoolResultMixin, Request):
 
     chat_id: Union[int, str]
     action: ChatActionType
+    message_thread_id: Optional[int] = None
