@@ -22,6 +22,7 @@ class SendMediaGroup(Request):
 
     chat_id: Union[int, str]
     media: List[InputMedia]
+    message_thread_id: Optional[int] = None
     disable_notification: Optional[bool] = None
     protect_content: Optional[bool] = None
     reply_to_message_id: Optional[int] = None
@@ -34,8 +35,8 @@ class SendMediaGroup(Request):
             if hasattr(e, 'media') and isinstance(e.media, InputFile):
                 out.append(e.media)
                 continue
-            if hasattr(e, 'thumb') and isinstance(e.thumb, InputFile):
-                out.append(e.thumb)
+            if hasattr(e, 'thumbnail') and isinstance(e.thumbnail, InputFile):
+                out.append(e.thumbnail)
 
         return out
 
