@@ -22,9 +22,11 @@ class SendPhoto(MessageResultMixin, Request):
 
     chat_id: Union[int, str]
     photo: Union[InputFile, str]
+    message_thread_id: Optional[int] = None
     caption: Optional[str] = None
     parse_mode: Optional[ParseModeType] = None
     caption_entities: Optional[List[MessageEntity]] = None
+    has_spoiler: Optional[bool] = None
     disable_notification: Optional[bool] = None
     protect_content: Optional[bool] = None
     reply_to_message_id: Optional[int] = None
