@@ -5,17 +5,13 @@
 
 import asyncio
 import logging
+from secrets import compare_digest
 
 from aiohttp.web import Server, ServerRunner, BaseRequest, TCPSite, Response
 
 from .webhook import WebhookExecutor
 from ..api import Request, Update
 
-try:
-    import ujson as json
-except ImportError:
-    import json
-
 logger = logging.getLogger('rocketgram.executors.aiohttp')
 
 
@@ -32,11 +28,14 @@ class AioHttpExecutor(WebhookExecutor):
             logger.warning("Bot not found for request `%s`.", request.path)
             return Response(status=404, text="Not found.", headers=self.HEADERS_ERROR)
 
-        if bot not in self._tasks:
-            self._tasks[bot] = set()
+        token = self._secret_tokens.get(bot)
+
+        if token and not compare_digest(token, request.headers.get(self.HEADER_SECRET, '')):
+            logger.warning("Wrong token was provided for the bot `%s`.", bot.name)
+            return Response(status=403, text="Wrong token.", headers=self.HEADERS_ERROR)
 
         try:
-            parsed = Update.parse(json.loads(await request.read()))
+            parsed = Update.parse(self._loads(await request.read()))
         except Exception:  # noqa
             logger.exception("Got exception while parsing update:")
             return Response(status=500, text="Server error.", headers=self.HEADERS_ERROR)
@@ -51,7 +50,7 @@ class AioHttpExecutor(WebhookExecutor):
             return Response(status=500, text="Server error.", headers=self.HEADERS_ERROR)
 
         if response:
-            data = json.dumps(response.render(with_method=True))
+            data = self._dumps(response.render(with_method=True))
             return Response(body=data, headers=self.HEADERS)
 
         self._tasks[bot] = {t for t in self._tasks[bot] if not t.done()}
