@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -22,7 +22,7 @@ def next_message(*message_types: MessageType):
     if not message_types:
         message_types = (MessageType.text,)
 
-    if context.message.message_type in message_types:
+    if context.message.type in message_types:
         return True
 
     return False
