@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by Vd.
+# Copyright (C) 2015-2022 by Vd.
 # This file is part of Rocketgram, the modern Telegram bot framework.
 # Rocketgram is released under the MIT License (see LICENSE).
 
@@ -19,6 +19,7 @@ HTML = {
     EntityType.italic: Tag('<i>', '</i>'),
     EntityType.underline: Tag('<u>', '</u>'),
     EntityType.strikethrough: Tag('<s>', '</s>'),
+    EntityType.spoiler: Tag('<span class="tg-spoiler">', '</span>'),
     EntityType.code: Tag('<code>', '</code>'),
     EntityType.pre: Tag('<pre>', '</pre>'),
     EntityType.text_link: Tag('<a href="%s">', '</a>'),
@@ -38,6 +39,7 @@ MARKDOWN2 = MARKDOWN.copy()
 MARKDOWN2.update({
     EntityType.underline: Tag('\r__\r', '\r__\r'),
     EntityType.strikethrough: Tag('~', '~'),
+    EntityType.spoiler: Tag('||', '||'),
 })
 
 
@@ -116,27 +118,33 @@ def to_html(text: Optional[str], entities: List[MessageEntity], escape_html: boo
     if text is None:
         return None
 
-    if entities is None:
-        return text
+    escape_func = escape.html if escape_html else lambda t: t
 
-    return parse(text, entities, get_html_tag, escape.html if escape_html else lambda t: t)
+    if entities is None:
+        return escape_func(text)
+
+    return parse(text, entities, get_html_tag, escape_func)
 
 
 def to_markdown(text: Optional[str], entities: List[MessageEntity], escape_markdown: bool = True) -> Optional[str]:
     if text is None:
         return None
 
-    if entities is None:
-        return text
+    escape_func = escape.markdown if escape_markdown else lambda t: t
 
-    return parse(text, entities, get_markdown_tag, escape.markdown if escape_markdown else lambda t: t)
+    if entities is None:
+        return escape_func(text)
+
+    return parse(text, entities, get_markdown_tag, escape_func)
 
 
 def to_markdown2(text: Optional[str], entities: List[MessageEntity], escape_markdown2: bool = True) -> Optional[str]:
     if text is None:
         return None
 
-    if entities is None:
-        return text
+    escape_func = escape.markdown2 if escape_markdown2 else lambda t: t
 
-    return parse(text, entities, get_markdown2_tag, escape.markdown2 if escape_markdown2 else lambda t: t)
+    if entities is None:
+        return escape_func(text)
+
+    return parse(text, entities, get_markdown2_tag, escape_func)
